# pml
Python Minecraft Launcher Library - crossplatform, support forge, all version  
this project is ported version from [CmlLib](https://github.com/AlphaBs/MinecraftLauncherLibrary)

1.4.*  
tested : windows 10 / ubuntu(Linux)  
macOS does not work yet. (bug)

Contacts
-------------

Email : ksi123456ab@naver.com  
Discord : ksi123456ab#3719  

License
--------------

<a rel="license" href="http://creativecommons.org/licenses/by-nc/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-nc/4.0/88x31.png" /></a><br />This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-nc/4.0/">Creative Commons Attribution-NonCommercial 4.0 International License</a>.

****NO COMMERCIAL****

Dependency
-------------
Python 3.6.8  
requests 2.22  

Use venv

How To Use
-------------
install :  

    pip install pmlauncher

check sample script
[main.py](https://github.com/AlphaBs/pml/blob/master/main.py)
